==> silk-0.11.2.tar.gz: silk-0.11.2/src/libflowsource/test-probeconf.c <==
/*
** Copyright (C) 2005-2007 by Carnegie Mellon University.
**
** @OPENSOURCE_HEADER_START@
** 
** Use of the SILK system and related source code is subject to the terms 
** of the following licenses:
** 
** GNU Public License (GPL) Rights pursuant to Version 2, June 1991
** Government Purpose License Rights (GPLR) pursuant to DFARS 252.225-7013
** 
** NO WARRANTY
** 
** ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER 
** PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY 
** PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN 
** "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY 
** KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT 
** LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE, 
** MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE 
** OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT, 
** SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY 
** TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF 
** WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES. 
** LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF 
** CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON 
** CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE 
** DELIVERABLES UNDER THIS LICENSE.
** 
** Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie 
** Mellon University, its trustees, officers, employees, and agents from 
** all claims or demands made against them (and any related losses, 
** expenses, or attorney's fees) arising out of, or relating to Licensee's 
** and/or its sub licensees' negligent use or willful misuse of or 
** negligent conduct or willful misconduct regarding the Software, 
** facilities, or other rights or assistance granted by Carnegie Mellon 
** University under this License, including, but not limited to, any 
** claims of product liability, personal injury, death, damage to 
** property, or violation of any laws or regulations.
** 
** Carnegie Mellon University Software Engineering Institute authored 
** documents are sponsored by the U.S. Department of Defense under 
** Contract F19628-00-C-0003. Carnegie Mellon University retains 
** copyrights in all material produced under this contract. The U.S. 
** Government retains a non-exclusive, royalty-free license to publish or 
** reproduce these documents, or allow others to do so, for U.S. 
** Government purposes only pursuant to the copyright license under the 
** contract clause at 252.227.7013.
** 
** @OPENSOURCE_HEADER_END@
*/

/*
**  Simple tester for the probe configuration library and parser
**
*/

#include "silk.h"

RCSIDENT("$SiLK: test-probeconf.c 6947 2007-04-17 21:12:48Z mthomas $");

#include "utils.h"
#include "probeconf.h"
#include "sksite.h"


int main(int argc, char **argv)
{
    const probe_def_t *probe;
    size_t count, i;
    int arg_index;

    /* register the application */
    skAppRegister(argv[0]);
    sksiteOptionsRegister(SK_SITE_FLAG_CONFIG_FILE);

    /* parse the options */
    arg_index = optionsParse(argc, argv);
    if (arg_index < 0) {
        /* options parsing should print error */
        skAppUsage();           /* never returns */
    }

    /* ensure the site config file is initialized */
    if (sksiteConfigure(1)) {
        exit(EXIT_FAILURE);
    }

    /* check for correct number of args */
    if (arg_index == argc) {
        skAppPrintErr("need file name to parse");
        goto END;
    }
    if ((argc - arg_index) > 1) {
        skAppPrintErr("can only process one file");
    }

    probeConfSetup();

    /* parse it */
    probeConfParse(argv[arg_index]);

    count = probeConfProbeCount();
    printf("Successfully parsed %u probes\n", (unsigned int)count);
    for (i = 0; i < count; ++i) {
        probe = probeConfProbeGetByPosition(i);
        printf("\t %4u => %s\n",
               (unsigned int)i, skProbeGetUniqueName(probe));
    }

  END:
    probeConfTeardown();
    skAppUnregister();

    return 0;
}


/*
** Local Variables:
** mode:c
** indent-tabs-mode:nil
** c-basic-offset:4
** End:
*/

==> silk-1.1.3.tar.gz: silk-1.1.3/src/libflowsource/test-probeconf.c <==
/*
** Copyright (C) 2005-2008 by Carnegie Mellon University.
**
** @OPENSOURCE_HEADER_START@
**
** Use of the SILK system and related source code is subject to the terms
** of the following licenses:
**
** GNU Public License (GPL) Rights pursuant to Version 2, June 1991
** Government Purpose License Rights (GPLR) pursuant to DFARS 252.225-7013
**
** NO WARRANTY
**
** ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
** PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
** PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
** "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
** KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
** LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
** MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
** OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
** SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
** TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
** WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
** LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
** CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
** CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
** DELIVERABLES UNDER THIS LICENSE.
**
** Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
** Mellon University, its trustees, officers, employees, and agents from
** all claims or demands made against them (and any related losses,
** expenses, or attorney's fees) arising out of, or relating to Licensee's
** and/or its sub licensees' negligent use or willful misuse of or
** negligent conduct or willful misconduct regarding the Software,
** facilities, or other rights or assistance granted by Carnegie Mellon
** University under this License, including, but not limited to, any
** claims of product liability, personal injury, death, damage to
** property, or violation of any laws or regulations.
**
** Carnegie Mellon University Software Engineering Institute authored
** documents are sponsored by the U.S. Department of Defense under
** Contract F19628-00-C-0003. Carnegie Mellon University retains
** copyrights in all material produced under this contract. The U.S.
** Government retains a non-exclusive, royalty-free license to publish or
** reproduce these documents, or allow others to do so, for U.S.
** Government purposes only pursuant to the copyright license under the
** contract clause at 252.227.7013.
**
** @OPENSOURCE_HEADER_END@
*/

/*
**  Simple tester for the probe configuration library and parser
**
*/

#include "silk.h"

RCSIDENT("$SiLK: test-probeconf.c 10646 2008-02-25 23:00:56Z mthomas $");

#include "utils.h"
#include "probeconf.h"
#include "sksite.h"


int main(int argc, char **argv)
{
    skpc_probe_iter_t probe_iter;
    const skpc_probe_t *probe;
    skpc_sensor_iter_t sensor_iter;
    const skpc_sensor_t *sensor;
    size_t count, i;
    int arg_index;

    /* register the application */
    skAppRegister(argv[0]);
    sksiteOptionsRegister(SK_SITE_FLAG_CONFIG_FILE);

    /* parse the options */
    arg_index = skOptionsParse(argc, argv);
    if (arg_index < 0) {
        /* options parsing should print error */
        skAppUsage();           /* never returns */
    }

    /* ensure the site config file is initialized */
    if (sksiteConfigure(1)) {
        exit(EXIT_FAILURE);
    }

    /* check for correct number of args */
    if (arg_index == argc) {
        skAppPrintErr("Need file name to parse");
        goto END;
    }
    if ((argc - arg_index) > 1) {
        skAppPrintErr("Can only process one file");
    }

    skpcSetup();

    /* parse it */
    skpcParse(argv[arg_index], NULL);

    count = skpcCountProbes();
    printf("Successfully parsed %u probes\n", (unsigned int)count);

    i = 0;
    skpcProbeIteratorBind(&probe_iter);
    while (skpcProbeIteratorNext(&probe_iter, &probe)) {
        printf("\t %4u => %s\n",
               (unsigned int)i, skpcProbeGetName(probe));
        ++i;
    }
    assert(i == count);

    count = skpcCountSensors();
    printf("Successfully parsed %u sensors\n", (unsigned int)count);

    i = 0;
    skpcSensorIteratorBind(&sensor_iter);
    while (skpcSensorIteratorNext(&sensor_iter, &sensor)) {
        printf("\t %4u => %s\n",
               (unsigned int)i, skpcSensorGetName(sensor));
        ++i;
    }
    assert(i == count);

  END:
    skpcTeardown();
    skAppUnregister();

    return 0;
}


/*
** Local Variables:
** mode:c
** indent-tabs-mode:nil
** c-basic-offset:4
** End:
*/
